EXPORTS
	??0RSqlDatabase@@QAE@XZ @ 1 NONAME ; RSqlDatabase::RSqlDatabase(void)
	??0RSqlStatement@@QAE@XZ @ 2 NONAME ; RSqlStatement::RSqlStatement(void)
	?BindBinary@RSqlStatement@@QAEHHABVTDesC8@@@Z @ 3 NONAME ; int RSqlStatement::BindBinary(int, class TDesC8 const &)
	?BindInt64@RSqlStatement@@QAEHH_J@Z @ 4 NONAME ; int RSqlStatement::BindInt64(int, long long)
	?BindInt@RSqlStatement@@QAEHHH@Z @ 5 NONAME ; int RSqlStatement::BindInt(int, int)
	?BindNull@RSqlStatement@@QAEHH@Z @ 6 NONAME ; int RSqlStatement::BindNull(int)
	?BindReal@RSqlStatement@@QAEHHN@Z @ 7 NONAME ; int RSqlStatement::BindReal(int, double)
	?BindText@RSqlStatement@@QAEHHABVTDesC16@@@Z @ 8 NONAME ; int RSqlStatement::BindText(int, class TDesC16 const &)
	?Close@RSqlDatabase@@QAEXXZ @ 9 NONAME ; void RSqlDatabase::Close(void)
	?Close@RSqlStatement@@QAEXXZ @ 10 NONAME ; void RSqlStatement::Close(void)
	?ColumnBinary@RSqlStatement@@QBEHHAAVTDes8@@@Z @ 11 NONAME ; int RSqlStatement::ColumnBinary(int, class TDes8 &) const
	?ColumnBinary@RSqlStatement@@QBEHHAAVTPtrC8@@@Z @ 12 NONAME ; int RSqlStatement::ColumnBinary(int, class TPtrC8 &) const
	?ColumnBinaryL@RSqlStatement@@QBE?AVTPtrC8@@H@Z @ 13 NONAME ; class TPtrC8 RSqlStatement::ColumnBinaryL(int) const
	?ColumnIndex@RSqlStatement@@QBEHABVTDesC16@@@Z @ 14 NONAME ; int RSqlStatement::ColumnIndex(class TDesC16 const &) const
	?ColumnInt64@RSqlStatement@@QBE_JH@Z @ 15 NONAME ; long long RSqlStatement::ColumnInt64(int) const
	?ColumnInt@RSqlStatement@@QBEHH@Z @ 16 NONAME ; int RSqlStatement::ColumnInt(int) const
	?ColumnReal@RSqlStatement@@QBENH@Z @ 17 NONAME ; double RSqlStatement::ColumnReal(int) const
	?ColumnSize@RSqlStatement@@QBEHH@Z @ 18 NONAME ; int RSqlStatement::ColumnSize(int) const
	?ColumnText@RSqlStatement@@QBEHHAAVTDes16@@@Z @ 19 NONAME ; int RSqlStatement::ColumnText(int, class TDes16 &) const
	?ColumnText@RSqlStatement@@QBEHHAAVTPtrC16@@@Z @ 20 NONAME ; int RSqlStatement::ColumnText(int, class TPtrC16 &) const
	?ColumnTextL@RSqlStatement@@QBE?AVTPtrC16@@H@Z @ 21 NONAME ; class TPtrC16 RSqlStatement::ColumnTextL(int) const
	?ColumnType@RSqlStatement@@QBE?AW4TSqlColumnType@@H@Z @ 22 NONAME ; enum TSqlColumnType RSqlStatement::ColumnType(int) const
	?Create@RSqlDatabase@@QAEHABVTDesC16@@PBVTDesC8@@@Z @ 23 NONAME ; int RSqlDatabase::Create(class TDesC16 const &, class TDesC8 const *)
	?Create@RSqlDatabase@@QAEHABVTDesC16@@ABVRSqlSecurityPolicy@@PBVTDesC8@@@Z @ 24 NONAME ; int RSqlDatabase::Create(class TDesC16 const &, class RSqlSecurityPolicy const &, class TDesC8 const *)
	?Delete@RSqlDatabase@@SAHABVTDesC16@@@Z @ 25 NONAME ; int RSqlDatabase::Delete(class TDesC16 const &)
	?Exec@RSqlDatabase@@QAEHABVTDesC16@@@Z @ 26 NONAME ; int RSqlDatabase::Exec(class TDesC16 const &)
	?Exec@RSqlDatabase@@QAEHABVTDesC8@@@Z @ 27 NONAME ; int RSqlDatabase::Exec(class TDesC8 const &)
	?Exec@RSqlStatement@@QAEHXZ @ 28 NONAME ; int RSqlStatement::Exec(void)
	?IsNull@RSqlStatement@@QBEHH@Z @ 29 NONAME ; int RSqlStatement::IsNull(int) const
	?LastErrorMessage@RSqlDatabase@@QBE?AVTPtrC16@@XZ @ 30 NONAME ; class TPtrC16 RSqlDatabase::LastErrorMessage(void) const
	?Next@RSqlStatement@@QAEHXZ @ 31 NONAME ; int RSqlStatement::Next(void)
	?Open@RSqlDatabase@@QAEHABVTDesC16@@PBVTDesC8@@@Z @ 32 NONAME ; int RSqlDatabase::Open(class TDesC16 const &, class TDesC8 const *)
	?ColumnBinary@RSqlColumnReadStream@@QAEHAAVRSqlStatement@@H@Z @ 33 NONAME ; int RSqlColumnReadStream::ColumnBinary(class RSqlStatement &, int)
	?BindBinary@RSqlParamWriteStream@@QAEHAAVRSqlStatement@@H@Z @ 34 NONAME ; int RSqlParamWriteStream::BindBinary(class RSqlStatement &, int)
	?ColumnText@RSqlColumnReadStream@@QAEHAAVRSqlStatement@@H@Z @ 35 NONAME ; int RSqlColumnReadStream::ColumnText(class RSqlStatement &, int)
	?BindText@RSqlParamWriteStream@@QAEHAAVRSqlStatement@@H@Z @ 36 NONAME ; int RSqlParamWriteStream::BindText(class RSqlStatement &, int)
	?ParameterIndex@RSqlStatement@@QBEHABVTDesC16@@@Z @ 37 NONAME ; int RSqlStatement::ParameterIndex(class TDesC16 const &) const
	?Prepare@RSqlStatement@@QAEHAAVRSqlDatabase@@ABVTDesC16@@@Z @ 38 NONAME ; int RSqlStatement::Prepare(class RSqlDatabase &, class TDesC16 const &)
	?Prepare@RSqlStatement@@QAEHAAVRSqlDatabase@@ABVTDesC8@@@Z @ 39 NONAME ; int RSqlStatement::Prepare(class RSqlDatabase &, class TDesC8 const &)
	?Reset@RSqlStatement@@QAEHXZ @ 40 NONAME ; int RSqlStatement::Reset(void)
	?GetSecurityPolicy@RSqlDatabase@@QBEHAAVRSqlSecurityPolicy@@@Z @ 41 NONAME ; TInt RSqlDatabase::GetSecurityPolicy(RSqlSecurityPolicy&) const
	?SetIsolationLevel@RSqlDatabase@@QAEHW4TIsolationLevel@1@@Z @ 42 NONAME ; int RSqlDatabase::SetIsolationLevel(enum RSqlDatabase::TIsolationLevel)
	?AtRow@RSqlStatement@@QBEHXZ @ 43 NONAME ; int RSqlStatement::AtRow(void) const
	?Count@TSqlResourceTester@@SAHXZ @ 44 NONAME ; int TSqlResourceTester::Count(void)
	?Check@TSqlResourceTester@@SAXXZ @ 45 NONAME ; void TSqlResourceTester::Check(void)
	?Mark@TSqlResourceTester@@SAXXZ @ 46 NONAME ; void TSqlResourceTester::Mark(void)
	?SetDbHeapFailure@TSqlResourceTester@@SAXHH@Z @ 47 NONAME ; void TSqlResourceTester::SetDbHeapFailure(int, int)
	?SetHeapFailure@TSqlResourceTester@@SAXHH@Z @ 48 NONAME ; void TSqlResourceTester::SetHeapFailure(int, int)
	??0RSqlSecurityPolicy@@QAE@XZ @ 49 NONAME ; RSqlSecurityPolicy::RSqlSecurityPolicy(void)
	?Close@RSqlSecurityPolicy@@QAEXXZ @ 50 NONAME ; void RSqlSecurityPolicy::Close(void)
	?Create@RSqlSecurityPolicy@@QAEHABVTSecurityPolicy@@@Z @ 51 NONAME ; int RSqlSecurityPolicy::Create(class TSecurityPolicy const &)
	?DbPolicy@RSqlSecurityPolicy@@QBE?AVTSecurityPolicy@@W4TPolicyType@1@@Z @ 52 NONAME ; class TSecurityPolicy RSqlSecurityPolicy::DbPolicy(enum RSqlSecurityPolicy::TPolicyType) const
	?DefaultPolicy@RSqlSecurityPolicy@@QBE?AVTSecurityPolicy@@XZ @ 53 NONAME ; class TSecurityPolicy RSqlSecurityPolicy::DefaultPolicy(void) const
	?ExternalizeL@RSqlSecurityPolicy@@QBEXAAVRWriteStream@@@Z @ 54 NONAME ; void RSqlSecurityPolicy::ExternalizeL(class RWriteStream &) const
	?InternalizeL@RSqlSecurityPolicy@@QAEXAAVRReadStream@@@Z @ 55 NONAME ; void RSqlSecurityPolicy::InternalizeL(class RReadStream &)
	?Policy@RSqlSecurityPolicy@@QBE?AVTSecurityPolicy@@W4TObjectType@1@ABVTDesC16@@W4TPolicyType@1@@Z @ 56 NONAME ; class TSecurityPolicy RSqlSecurityPolicy::Policy(enum RSqlSecurityPolicy::TObjectType, class TDesC16 const &, enum RSqlSecurityPolicy::TPolicyType) const
	?SetDbPolicy@RSqlSecurityPolicy@@QAEHW4TPolicyType@1@ABVTSecurityPolicy@@@Z @ 57 NONAME ; int RSqlSecurityPolicy::SetDbPolicy(enum RSqlSecurityPolicy::TPolicyType, class TSecurityPolicy const &)
	?SetPolicy@RSqlSecurityPolicy@@QAEHW4TObjectType@1@ABVTDesC16@@W4TPolicyType@1@ABVTSecurityPolicy@@@Z @ 58 NONAME ; int RSqlSecurityPolicy::SetPolicy(enum RSqlSecurityPolicy::TObjectType, class TDesC16 const &, enum RSqlSecurityPolicy::TPolicyType, class TSecurityPolicy const &)
	?SqlRetCodeClass@@YA?AW4TSqlRetCodeClass@@H@Z @ 59 NONAME ; enum TSqlRetCodeClass SqlRetCodeClass(int)
	?Attach@RSqlDatabase@@QAEHABVTDesC16@@0@Z @ 60 NONAME ; int RSqlDatabase::Attach(class TDesC16 const &, class TDesC16 const &)
	?Detach@RSqlDatabase@@QAEHABVTDesC16@@@Z @ 61 NONAME ; int RSqlDatabase::Detach(class TDesC16 const &)
	?Copy@RSqlDatabase@@SAHABVTDesC16@@0@Z @ 62 NONAME ; int RSqlDatabase::Copy(class TDesC16 const &, class TDesC16 const &)
	?BindBinaryL@RSqlParamWriteStream@@QAEXAAVRSqlStatement@@H@Z @ 63 NONAME ; void RSqlParamWriteStream::BindBinaryL(class RSqlStatement &, int)
	?BindTextL@RSqlParamWriteStream@@QAEXAAVRSqlStatement@@H@Z @ 64 NONAME ; void RSqlParamWriteStream::BindTextL(class RSqlStatement &, int)
	?ColumnBinaryL@RSqlColumnReadStream@@QAEXAAVRSqlStatement@@H@Z @ 65 NONAME ; void RSqlColumnReadStream::ColumnBinaryL(class RSqlStatement &, int)
	?ColumnTextL@RSqlColumnReadStream@@QAEXAAVRSqlStatement@@H@Z @ 66 NONAME ; void RSqlColumnReadStream::ColumnTextL(class RSqlStatement &, int)
	?CreateL@RSqlDatabase@@QAEXABVTDesC16@@PBVTDesC8@@@Z @ 67 NONAME ; void RSqlDatabase::CreateL(class TDesC16 const &, class TDesC8 const *)
	?CreateL@RSqlDatabase@@QAEXABVTDesC16@@ABVRSqlSecurityPolicy@@PBVTDesC8@@@Z @ 68 NONAME ; void RSqlDatabase::CreateL(class TDesC16 const &, class RSqlSecurityPolicy const &, class TDesC8 const *)
	?OpenL@RSqlDatabase@@QAEXABVTDesC16@@PBVTDesC8@@@Z @ 69 NONAME ; void RSqlDatabase::OpenL(class TDesC16 const &, class TDesC8 const *)
	?PrepareL@RSqlStatement@@QAEXAAVRSqlDatabase@@ABVTDesC16@@@Z @ 70 NONAME ; void RSqlStatement::PrepareL(class RSqlDatabase &, class TDesC16 const &)
	?PrepareL@RSqlStatement@@QAEXAAVRSqlDatabase@@ABVTDesC8@@@Z @ 71 NONAME ; void RSqlStatement::PrepareL(class RSqlDatabase &, class TDesC8 const &)
	?CreateL@RSqlSecurityPolicy@@QAEXABVTSecurityPolicy@@@Z @ 72 NONAME ; void RSqlSecurityPolicy::CreateL(class TSecurityPolicy const &)
	?GetSecurityPolicyL@RSqlDatabase@@QBEXAAVRSqlSecurityPolicy@@@Z @ 73 NONAME ; void RSqlDatabase::GetSecurityPolicyL(class RSqlSecurityPolicy &) const
	?FreeReservedSpace@RSqlDatabase@@QAEXXZ @ 74 NONAME ; void RSqlDatabase::FreeReservedSpace(void)
	?GetReserveAccess@RSqlDatabase@@QAEHXZ @ 75 NONAME ; int RSqlDatabase::GetReserveAccess(void)
	?ReleaseReserveAccess@RSqlDatabase@@QAEXXZ @ 76 NONAME ; void RSqlDatabase::ReleaseReserveAccess(void)
	?ReserveDriveSpace@RSqlDatabase@@QAEHH@Z @ 77 NONAME ; int RSqlDatabase::ReserveDriveSpace(int)
	?Exec@RSqlDatabase@@QAEXABVTDesC16@@AAVTRequestStatus@@@Z @ 78 NONAME ; void RSqlDatabase::Exec(class TDesC16 const &, class TRequestStatus &)
	?Exec@RSqlDatabase@@QAEXABVTDesC8@@AAVTRequestStatus@@@Z @ 79 NONAME ; void RSqlDatabase::Exec(class TDesC8 const &, class TRequestStatus &)
	?Exec@RSqlStatement@@QAEXAAVTRequestStatus@@@Z @ 80 NONAME ; void RSqlStatement::Exec(class TRequestStatus &)
	??0TSqlScalarFullSelectQuery@@QAE@AAVRSqlDatabase@@@Z @ 81 NONAME ; TSqlScalarFullSelectQuery::TSqlScalarFullSelectQuery(class RSqlDatabase &)
	??0TSqlScalarFullSelectQuery@@QAE@XZ @ 82 NONAME ; TSqlScalarFullSelectQuery::TSqlScalarFullSelectQuery(void)
	?SelectBinaryL@TSqlScalarFullSelectQuery@@QAEHABVTDesC16@@AAVTDes8@@@Z @ 83 NONAME ; int TSqlScalarFullSelectQuery::SelectBinaryL(class TDesC16 const &, class TDes8 &)
	?SelectBinaryL@TSqlScalarFullSelectQuery@@QAEHABVTDesC8@@AAVTDes8@@@Z @ 84 NONAME ; int TSqlScalarFullSelectQuery::SelectBinaryL(class TDesC8 const &, class TDes8 &)
	?SelectInt64L@TSqlScalarFullSelectQuery@@QAE_JABVTDesC16@@@Z @ 85 NONAME ; long long TSqlScalarFullSelectQuery::SelectInt64L(class TDesC16 const &)
	?SelectInt64L@TSqlScalarFullSelectQuery@@QAE_JABVTDesC8@@@Z @ 86 NONAME ; long long TSqlScalarFullSelectQuery::SelectInt64L(class TDesC8 const &)
	?SelectIntL@TSqlScalarFullSelectQuery@@QAEHABVTDesC16@@@Z @ 87 NONAME ; int TSqlScalarFullSelectQuery::SelectIntL(class TDesC16 const &)
	?SelectIntL@TSqlScalarFullSelectQuery@@QAEHABVTDesC8@@@Z @ 88 NONAME ; int TSqlScalarFullSelectQuery::SelectIntL(class TDesC8 const &)
	?SelectRealL@TSqlScalarFullSelectQuery@@QAENABVTDesC16@@@Z @ 89 NONAME ; double TSqlScalarFullSelectQuery::SelectRealL(class TDesC16 const &)
	?SelectRealL@TSqlScalarFullSelectQuery@@QAENABVTDesC8@@@Z @ 90 NONAME ; double TSqlScalarFullSelectQuery::SelectRealL(class TDesC8 const &)
	?SelectTextL@TSqlScalarFullSelectQuery@@QAEHABVTDesC16@@AAVTDes16@@@Z @ 91 NONAME ; int TSqlScalarFullSelectQuery::SelectTextL(class TDesC16 const &, class TDes16 &)
	?SelectTextL@TSqlScalarFullSelectQuery@@QAEHABVTDesC8@@AAVTDes16@@@Z @ 92 NONAME ; int TSqlScalarFullSelectQuery::SelectTextL(class TDesC8 const &, class TDes16 &)
	?SetDatabase@TSqlScalarFullSelectQuery@@QAEXAAVRSqlDatabase@@@Z @ 93 NONAME ; void TSqlScalarFullSelectQuery::SetDatabase(class RSqlDatabase &)
	?InTransaction@RSqlDatabase@@QBEHXZ @ 94 NONAME ; int RSqlDatabase::InTransaction(void) const
	?Size@RSqlDatabase@@QBEHXZ @ 95 NONAME ; int RSqlDatabase::Size(void) const
	?BindText8@TSqlRowSetUtil@@SAHAAVRSqlStatement@@HABVTDesC8@@@Z @ 96 NONAME ABSENT ; int TSqlRowSetUtil::BindText8(class RSqlStatement &, int, class TDesC8 const &)
	?ColumnNamesL@TSqlRowSetUtil@@SAABVTDesC8@@AAVRSqlStatement@@@Z @ 97 NONAME ABSENT ; class TDesC8 const & TSqlRowSetUtil::ColumnNamesL(class RSqlStatement &)
	?ColumnSourceL@TSqlRowSetUtil@@SAPAVMStreamBuf@@ABVRSqlStatement@@H@Z @ 98 NONAME ABSENT ; class MStreamBuf * TSqlRowSetUtil::ColumnSourceL(class RSqlStatement const &, int)
	?ColumnValuesL@TSqlRowSetUtil@@SAABVTDesC8@@AAVRSqlStatement@@_J@Z @ 99 NONAME ABSENT ; class TDesC8 const & TSqlRowSetUtil::ColumnValuesL(class RSqlStatement &, long long)
	?CreateDb@TSqlRowSetUtil@@SAHAAVRSqlDatabase@@ABVTDesC16@@PBVTDesC8@@@Z @ 100 NONAME ABSENT ; int TSqlRowSetUtil::CreateDb(class RSqlDatabase &, class TDesC16 const &, class TDesC8 const *)
	?EvaluateAll@TSqlRowSetUtil@@SAHAAVRSqlStatement@@AAV?$RArray@_J@@@Z @ 101 NONAME ABSENT ; int TSqlRowSetUtil::EvaluateAll(class RSqlStatement &, class RArray<long long> &)
	?Exec@TSqlRowSetUtil@@SAHAAVRSqlDatabase@@ABVTDesC16@@AA_J@Z @ 102 NONAME ABSENT ; int TSqlRowSetUtil::Exec(class RSqlDatabase &, class TDesC16 const &, long long &)
	?GetColumnValue@TSqlRowSetUtil@@SAHAAVRSqlStatement@@HAAVTDes8@@@Z @ 103 NONAME ABSENT ; int TSqlRowSetUtil::GetColumnValue(class RSqlStatement &, int, class TDes8 &)
	?GetDeclColumnTypesL@TSqlRowSetUtil@@SAPAVHBufC16@@AAVRSqlStatement@@@Z @ 104 NONAME ABSENT ; class HBufC16 * TSqlRowSetUtil::GetDeclColumnTypesL(class RSqlStatement &)
	?Insert@TSqlRowSetUtil@@SAHAAVRSqlStatement@@AA_J@Z @ 105 NONAME ABSENT ; int TSqlRowSetUtil::Insert(class RSqlStatement &, long long &)
	?OpenDb@TSqlRowSetUtil@@SAHAAVRSqlDatabase@@ABVTDesC16@@PBVTDesC8@@@Z @ 106 NONAME ABSENT ; int TSqlRowSetUtil::OpenDb(class RSqlDatabase &, class TDesC16 const &, class TDesC8 const *)
	?Update@TSqlRowSetUtil@@SAHAAVRSqlStatement@@@Z @ 107 NONAME ABSENT ; int TSqlRowSetUtil::Update(class RSqlStatement &)
	?ColumnValues@TSqlRowSetUtil@@SAABVTDesC8@@AAVRSqlStatement@@@Z @ 108 NONAME ABSENT ; class TDesC8 const & TSqlRowSetUtil::ColumnValues(class RSqlStatement &)
	?ColumnCount@RSqlStatement@@QBEHXZ @ 109 NONAME ; int RSqlStatement::ColumnCount(void) const
	?DeclaredColumnType@RSqlStatement@@QBEHHAAW4TSqlColumnType@@@Z @ 110 NONAME ; int RSqlStatement::DeclaredColumnType(int, enum TSqlColumnType &) const
	?ColumnName@RSqlStatement@@QAEHHAAVTPtrC16@@@Z @ 111 NONAME ; int RSqlStatement::ColumnName(int, class TPtrC16 &)
	?ParameterName@RSqlStatement@@QAEHHAAVTPtrC16@@@Z @ 112 NONAME ; int RSqlStatement::ParameterName(int, class TPtrC16 &)
	??0TSqlResourceProfiler@@QAE@AAVRSqlDatabase@@@Z @ 113 NONAME ; TSqlResourceProfiler::TSqlResourceProfiler(class RSqlDatabase &)
	?BindZeroBlob@RSqlStatement@@QAEHHH@Z @ 114 NONAME ; int RSqlStatement::BindZeroBlob(int, int)
	?Compact@RSqlDatabase@@QAEH_JABVTDesC16@@@Z @ 115 NONAME ; int RSqlDatabase::Compact(long long, class TDesC16 const &)
	?Compact@RSqlDatabase@@QAEX_JAAVTRequestStatus@@ABVTDesC16@@@Z @ 116 NONAME ; void RSqlDatabase::Compact(long long, class TRequestStatus &, class TDesC16 const &)
	?Get@TSqlBlob@@SAHAAVRSqlDatabase@@ABVTDesC16@@1AAVTDes8@@_J1@Z @ 117 NONAME ; int TSqlBlob::Get(class RSqlDatabase &, class TDesC16 const &, class TDesC16 const &, class TDes8 &, long long, class TDesC16 const &)
	?GetLC@TSqlBlob@@SAPAVHBufC8@@AAVRSqlDatabase@@ABVTDesC16@@1_J1@Z @ 118 NONAME ; class HBufC8 * TSqlBlob::GetLC(class RSqlDatabase &, class TDesC16 const &, class TDesC16 const &, long long, class TDesC16 const &)
	?LastInsertedRowId@RSqlDatabase@@QBE_JXZ @ 119 NONAME ; long long RSqlDatabase::LastInsertedRowId(void) const
	?OpenL@RSqlBlobReadStream@@QAEXAAVRSqlDatabase@@ABVTDesC16@@1_J1@Z @ 120 NONAME ; void RSqlBlobReadStream::OpenL(class RSqlDatabase &, class TDesC16 const &, class TDesC16 const &, long long, class TDesC16 const &)
	?OpenL@RSqlBlobWriteStream@@QAEXAAVRSqlDatabase@@ABVTDesC16@@1_J1@Z @ 121 NONAME ; void RSqlBlobWriteStream::OpenL(class RSqlDatabase &, class TDesC16 const &, class TDesC16 const &, long long, class TDesC16 const &)
	?Query@TSqlResourceProfiler@@QAEHW4TSqlCounter@1@AAVTDes8@@@Z @ 122 NONAME ; int TSqlResourceProfiler::Query(enum TSqlResourceProfiler::TSqlCounter, class TDes8 &)
	?Reset@TSqlResourceProfiler@@QAEHW4TSqlCounter@1@@Z @ 123 NONAME ; int TSqlResourceProfiler::Reset(enum TSqlResourceProfiler::TSqlCounter)
	?SetL@TSqlBlob@@SAXAAVRSqlDatabase@@ABVTDesC16@@1ABVTDesC8@@_J1@Z @ 124 NONAME ; void TSqlBlob::SetL(class RSqlDatabase &, class TDesC16 const &, class TDesC16 const &, class TDesC8 const &, long long, class TDesC16 const &)
	?Size@RSqlDatabase@@QBEHAAUTSize@1@ABVTDesC16@@@Z @ 125 NONAME ; int RSqlDatabase::Size(struct RSqlDatabase::TSize &, class TDesC16 const &) const
	?SizeL@RSqlBlobReadStream@@QAEHXZ @ 126 NONAME ; int RSqlBlobReadStream::SizeL(void)
	?SizeL@RSqlBlobWriteStream@@QAEHXZ @ 127 NONAME ; int RSqlBlobWriteStream::SizeL(void)
	?Start@TSqlResourceProfiler@@QAEHW4TSqlCounter@1@PBVTDesC8@@@Z @ 128 NONAME ; int TSqlResourceProfiler::Start(enum TSqlResourceProfiler::TSqlCounter, class TDesC8 const *)
	?Stop@TSqlResourceProfiler@@QAEHW4TSqlCounter@1@@Z @ 129 NONAME ; int TSqlResourceProfiler::Stop(enum TSqlResourceProfiler::TSqlCounter)
	?ParamName@RSqlStatement@@QAEHHAAVTPtrC16@@@Z @ 130 NONAME ; int RSqlStatement::ParamName(int, class TPtrC16 &)

